@@ -23,7 +23,7 @@ use File::Basename ();
 use File::Path ();
 
 # ABSTRACT: Test an imaginary beowulf cluster of Clustericious services
-our $VERSION = '0.24'; # VERSION
+our $VERSION = '0.25'; # VERSION
 
 
 BEGIN { $ENV{MOJO_LOG_LEVEL} = 'fatal' }
@@ -317,7 +317,7 @@ sub create_cluster_ok
         }
         $app_name->new(\$config);
       };
-      my $first_try_error = $@;
+      $first_try_error = $@;
     }
 
     unless(defined $app)
@@ -574,7 +574,7 @@ Test::Clustericious::Cluster - Test an imaginary beowulf cluster of Clustericiou
 
 =head1 VERSION
 
-version 0.24
+version 0.25
 
 =head1 SYNOPSIS
 
